import { ComponentFactoryResolver, Injector, ApplicationRef } from '@angular/core';
import * as i0 from "@angular/core";
export declare class TooltipService {
    private readonly _injector;
    private readonly _applicationRef;
    private readonly _tooltipComponentFactory;
    private _tooltipRef;
    constructor(_injector: Injector, _applicationRef: ApplicationRef, componentFactoryResolver: ComponentFactoryResolver);
    /**
     * Programmatically show tooltip anchored at the element specified by `target`
     *
     * @param target The element at which to place the tooltip.
     * @param content Tooltip's body's content, it can contain HTML
     * @param placement Where the tooltip should be anchored at, `bottom` is the default
     */
    show(target: HTMLElement | SVGElement, content: string, placement?: 'top' | 'right' | 'bottom' | 'left'): void;
    /**
     * A helper method used to create new tooltip component refs
     *
     * @param content Tooltip's body's content, it can contain HTML
     * @param placement Where the tooltip should be anchored at
     * @returns
     */
    private _createTooltip;
    /**
     * Mount `tooltipRef` and make its host element a direct child of `document.body`
     *
     * @param tooltipRef
     */
    private _mountTooltip;
    /**
     * Show tooltip at a specific x/y location
     *
     * @param x The x location
     * @param y The y location
     * @param content Tooltip's body's content, it can contain HTML
     * @param placement Where the tooltip should be anchored at, `bottom` is the default
     */
    showAt(x: number, y: number, content: string, placement?: 'top' | 'right' | 'bottom' | 'left'): void;
    /**
     * Hide the currently active tooltip
     */
    hide(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TooltipService>;
}
